\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{comnets}[Template for Master or bachelor theses]
\LoadClass[a4paper,twoside,10pt]{book}

\RequirePackage[utf8]{inputenc}             % UTF-8 source file encoding
\RequirePackage{amssymb}                    % Mathematical symbols and functions
\RequirePackage{amsmath}                    % Mathematical symbols and functions
\RequirePackage{amsfonts}                   % Mathematical symbols and fonts
\RequirePackage{amsthm}                     % Mathematical theorems
\RequirePackage{latexsym}                   % Mathematical symbols
\RequirePackage{enumerate}                  % Creates numbered lists
\RequirePackage{mathtools}                  % Mathematical commands
\RequirePackage{float}                      % Floating objects
\RequirePackage{lipsum}                     % Dummy text
\RequirePackage[top = 2.5cm, bottom = 2cm, left = 3cm, right = 2.5cm]{geometry}
\RequirePackage{graphicx}                   % For floating figures
\RequirePackage{fancyhdr}                   % Designable header and footer
\RequirePackage{fancybox}                   % Designable header and footer
\RequirePackage{calc}                       % Arithmetic and calculation tools
\RequirePackage{color}                      % Color of text backgrounds and lines
\RequirePackage{xcolor}                     % Color of text backgrounds and lines
\RequirePackage[T1]{fontenc}                % Encoding of the fonts
\RequirePackage{iflang}                     % For eng / ger 
\RequirePackage{helvet}   
\renewcommand{\familydefault}{\sfdefault}
\fontfamily{phv}\selectfont

\RequirePackage{mathrsfs}                   % Mathematical calligraphic font
\RequirePackage{hyperref}                   % Creating hyperlinks
\RequirePackage{caption}                    % caption for figures
\RequirePackage{subcaption}                 % Sub figures within a  figure

\RequirePackage{textcomp}                   % Additional symbols
\RequirePackage{gensymb}                    % Mathematical symbols
\RequirePackage{exscale}                    % Scalable mathematical symbols
\RequirePackage{comment}                    % Inserting comments
\RequirePackage{siunitx}                    % Automatic spacing for numbers and units

\RequirePackage{url}                        % Typesetting URLs
\RequirePackage{parskip}                    % Vertical whitespace
\RequirePackage{sectsty}                    % Customize section headings
\RequirePackage{setspace}
\RequirePackage{enumitem,amssymb}
\newlist{todolist}{itemize}{2}
\setlist[todolist]{label=$\square$}

%Custom fontsize
\sectionfont{\fontsize{16}{18}\selectfont}
\subsectionfont{\fontsize{12}{14}\selectfont}

%Line spacing set to 1.5
\renewcommand{\baselinestretch}{1.5} 

%Custom header and footer
\pagestyle{fancy}
\setlength{\footskip}{40pt}

%\setlength{\headheight}{36pt}
%\setlength{\footskip}{37pt}

\renewcommand{\headrulewidth}{0.5pt}
\renewcommand{\headrule}{\color{gray}\hrule}
\renewcommand{\footrulewidth}{0.5pt}
\renewcommand{\footrule}{\color{gray}\hrule}


\fancyhead{}
\fancyhead[RO,LE]{\@title}
\fancyfoot{}
\fancyfoot[LE,RO]{\thepage}
\fancyfoot[RE,LO]{\includegraphics[height=0.5cm]{assets/comnets_logo}}

\fancypagestyle{plain}{%
\fancyhead{}
\fancyfoot{}
\fancyfoot[LE,RO]{\thepage}
\fancyfoot[RE,LO]{\includegraphics[height=0.5cm]{assets/comnets_logo}}
}

% Make sure the fancyhdr is also used for special pages:
%\addtocontents{lof}{\protect\thispagestyle{fancy}}% List of figures
%\addtocontents{toc}{\protect\thispagestyle{fancy}}% Table of contents
%\addtocontents{lot}{\protect\thispagestyle{fancy}}% List of tables